summaryrefslogtreecommitdiffstats
path: root/settings/templates/admin.php
diff options
context:
space:
mode:
authorStefan Weil <sw@weilnetz.de>2016-07-28 23:00:00 +0200
committerStefan Weil <sw@weilnetz.de>2016-07-29 11:06:32 +0200
commitbb8a42bd44e2351fd5880cb8abea6bd1d8aab687 (patch)
treec11b99b8e13b2e5e5ea1cef0a826d5a35cffa708 /settings/templates/admin.php
parent41d044cf89d8df6ed2233bd24da3469cf145760c (diff)
downloadnextcloud-server-bb8a42bd44e2351fd5880cb8abea6bd1d8aab687.tar.gz
nextcloud-server-bb8a42bd44e2351fd5880cb8abea6bd1d8aab687.zip
Fix misspelling of database "READ COMMITTED"
Signed-off-by: Stefan Weil <sw@weilnetz.de>
Diffstat (limited to 'settings/templates/admin.php')
-rw-r--r--settings/templates/admin.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/settings/templates/admin.php b/settings/templates/admin.php
index 2524c9c2013..74fe585962d 100644
--- a/settings/templates/admin.php
+++ b/settings/templates/admin.php
@@ -97,11 +97,11 @@ if (!$_['isAnnotationsWorking']) {
<?php
}
// Is the Transaction isolation level READ_COMMITED?
if ($_['invalidTransactionIsolationLevel']) {
?>
<li>
- <?php p($l->t('Your database does not run with "READ COMMITED" transaction isolation level. This can cause problems when multiple actions are executed in parallel.')); ?>
+ <?php p($l->t('Your database does not run with "READ COMMITTED" transaction isolation level. This can cause problems when multiple actions are executed in parallel.')); ?>
</li>
<?php
}
@@ -97,11 +97,11 @@ if (!$_['isAnnotationsWorking']) {
<?php
}
-// Is the Transaction isolation level READ_COMMITED?
+// Is the Transaction isolation level READ_COMMITTED?
if ($_['invalidTransactionIsolationLevel']) {
?>